import os

from ml import predictor
from django.shortcuts import render
from django.views import View
from django.core.files.storage import FileSystemStorage

class Index(View):
    submitted = False
    def __init__(self):
        self._template = 'index.html'
        self._checkpoint_path = 'ml/model/checkpoint.pth'

        self._predictor = predictor.Predictor(self._checkpoint_path)
        self._classes = self._predictor.classes

    def get(self, request):
        return render(request, self._template)

    def predict_image(self, request):
        image_obj = request.FILES.get('filePath', None)

        # if user did not upload an image, refresh
        if image_obj is None:
            return render(request, 'upload.html')

        fs = FileSystemStorage()

        # save the file and get the path
        image_name = fs.get_available_name(image_obj.name)
        image_path = fs.save(image_name, image_obj)
        image_path = fs.url(image_path)
        full_image_path = os.path.join('finder', 'static', 'media', image_name)

        # get prediction
        pred_confs, pred_classes = self._predictor.predict(full_image_path)
        predicted_class = self._classes[pred_classes[0]]
        
        # plot confidence scores
        plot_image_name = fs.get_available_name('plot.png')
        plot_image_path = os.path.join('media', plot_image_name)
        full_plot_image_path = os.path.join('finder', 'static', plot_image_path)
        self._predictor.plot_predictions(pred_confs, pred_classes, full_plot_image_path)

        submitted = True

        # update upload.html with context
        context={
            'predictedLabel': predicted_class,
            'imagePath': image_path,
            'plotImagePath': f'/{plot_image_path}',
            'submitted': submitted
        }
        return render(request,'upload.html',context)




#!/usr/bin/env python
import os
import sys
#from sample_app import sample_data

def main():
    os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'carfinder.settings')
    try:
        from django.core.management import execute_from_command_line
    except ImportError as exc:
        raise ImportError("Couldn't import Django.") from exc

    execute_from_command_line(["manage.py", "makemigrations"])
    execute_from_command_line(["manage.py", "migrate"])
    #sample_data.generate()

if __name__ == '__main__':
    main()


from django import forms
from django.shortcuts import get_object_or_404, render
from django.http import HttpResponseRedirect
4

class ImageUploadForm(forms.Form):
    fname = forms.CharField(max_length=100, label='Name')
    lname = forms.CharField(max_length=100, label='Name')
    email = forms.EmailField(required=False, label='Email address')
    image = forms.ImageField()


def upload(request):
    submitted = False
    if request.method == 'POST':
        form = ImageUploadForm(request.POST)
        if form.is_valid():
            cd = form.cleaned_data
            # assert False
            return HttpResponseRedirect('/upload?submitted=True')
    else:
        form = ImageUploadForm()
        if 'submitted' in request.GET:
            submitted = True

    return render(request, 'upload.html', {'form': form, 'submitted': submitted})
